// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: sentencepiece.proto
// Protobuf C++ Version: 7.35.1

#ifndef sentencepiece_2eproto_2epb_2eh
#define sentencepiece_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_sentencepiece_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_sentencepiece_2eproto {
  static const ::uint32_t offsets[];
};
namespace sentencepiece {
class NBestSentencePieceText;
struct NBestSentencePieceTextGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern NBestSentencePieceTextGlobalsTypeInternal NBestSentencePieceText_globals_;
extern const ::google::protobuf::internal::ClassDataLite NBestSentencePieceText_class_data_;
#else
extern const NBestSentencePieceTextGlobalsTypeInternal NBestSentencePieceText_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class SentencePieceText;
struct SentencePieceTextGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern SentencePieceTextGlobalsTypeInternal SentencePieceText_globals_;
extern const ::google::protobuf::internal::ClassDataLite SentencePieceText_class_data_;
#else
extern const SentencePieceTextGlobalsTypeInternal SentencePieceText_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class SentencePieceText_SentencePiece;
struct SentencePieceText_SentencePieceGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern SentencePieceText_SentencePieceGlobalsTypeInternal SentencePieceText_SentencePiece_globals_;
extern const ::google::protobuf::internal::ClassDataLite SentencePieceText_SentencePiece_class_data_;
#else
extern const SentencePieceText_SentencePieceGlobalsTypeInternal SentencePieceText_SentencePiece_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
}  // namespace sentencepiece
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace sentencepiece {

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED SentencePieceText_SentencePiece final : public ::google::protobuf::MessageLite
/* @@protoc_insertion_point(class_definition:sentencepiece.SentencePieceText.SentencePiece) */ {
 public:
  inline SentencePieceText_SentencePiece() : SentencePieceText_SentencePiece(nullptr) {}
  ~SentencePieceText_SentencePiece() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(SentencePieceText_SentencePiece* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(SentencePieceText_SentencePiece));
  }
#endif

  template <typename = void>
  explicit constexpr SentencePieceText_SentencePiece(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline SentencePieceText_SentencePiece(const SentencePieceText_SentencePiece& from) : SentencePieceText_SentencePiece(nullptr, from) {}
  inline SentencePieceText_SentencePiece(SentencePieceText_SentencePiece&& from) noexcept : SentencePieceText_SentencePiece(nullptr, ::std::move(from)) {}
  inline SentencePieceText_SentencePiece& operator=(const SentencePieceText_SentencePiece& from) {
    CopyFrom(from);
    return *this;
  }
  inline SentencePieceText_SentencePiece& operator=(SentencePieceText_SentencePiece&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::std::string& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString);
  }
  [[nodiscard]] inline ::std::string* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::std::string>();
  }

  [[nodiscard]] static const SentencePieceText_SentencePiece& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<SentencePieceText_SentencePiece>(&SentencePieceText_SentencePiece_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(SentencePieceText_SentencePiece& a, SentencePieceText_SentencePiece& b) { a.Swap(&b); }
  inline void Swap(SentencePieceText_SentencePiece* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SentencePieceText_SentencePiece* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] SentencePieceText_SentencePiece* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::MessageLite::DefaultConstruct<SentencePieceText_SentencePiece>(arena);
  }
  void CopyFrom(const SentencePieceText_SentencePiece& from);
  void MergeFrom(const SentencePieceText_SentencePiece& from) { SentencePieceText_SentencePiece::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return IsInitializedImpl(*this);
  }

  private:
  static bool IsInitializedImpl(const MessageLite& msg);

  public:
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(SentencePieceText_SentencePiece* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "sentencepiece.SentencePieceText.SentencePiece"; }

  explicit SentencePieceText_SentencePiece(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  SentencePieceText_SentencePiece(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const SentencePieceText_SentencePiece& from);
  SentencePieceText_SentencePiece(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, SentencePieceText_SentencePiece&& from) noexcept
      : SentencePieceText_SentencePiece(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kPieceFieldNumber = 1,
    kSurfaceFieldNumber = 3,
    kIdFieldNumber = 2,
    kBeginFieldNumber = 4,
    kEndFieldNumber = 5,
  };
  // optional string piece = 1;
  [[nodiscard]] bool has_piece()
      const;
  void clear_piece() ;
  [[nodiscard]] const ::std::string& piece() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_piece(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_piece();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_piece();
  void set_allocated_piece(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_piece() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_piece(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_piece();

  public:
  // optional string surface = 3;
  [[nodiscard]] bool has_surface()
      const;
  void clear_surface() ;
  [[nodiscard]] const ::std::string& surface() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_surface(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_surface();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_surface();
  void set_allocated_surface(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_surface() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_surface(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_surface();

  public:
  // optional uint32 id = 2;
  [[nodiscard]] bool has_id()
      const;
  void clear_id() ;
  [[nodiscard]] ::uint32_t id() const;
  void set_id(::uint32_t value);

  private:
  ::uint32_t _internal_id() const;
  void _internal_set_id(::uint32_t value);

  public:
  // optional uint32 begin = 4;
  [[nodiscard]] bool has_begin()
      const;
  void clear_begin() ;
  [[nodiscard]] ::uint32_t begin() const;
  void set_begin(::uint32_t value);

  private:
  ::uint32_t _internal_begin() const;
  void _internal_set_begin(::uint32_t value);

  public:
  // optional uint32 end = 5;
  [[nodiscard]] bool has_end()
      const;
  void clear_end() ;
  [[nodiscard]] ::uint32_t end() const;
  void set_end(::uint32_t value);

  private:
  ::uint32_t _internal_end() const;
  void _internal_set_end(::uint32_t value);

  public:
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            typename = typename _proto_TypeTraits::Singular>
  PROTOBUF_FUTURE_ADD_NODISCARD inline bool HasExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) const {
    return _impl_._extensions_.Has(id.number());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void ClearExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) {
    _impl_._extensions_.ClearExtension(id.number());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            typename = typename _proto_TypeTraits::Repeated>
  PROTOBUF_FUTURE_ADD_NODISCARD inline int ExtensionSize(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) const {
    return _impl_._extensions_.ExtensionSize(id.number());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<!_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Singular::ConstType
      GetExtension(const ::google::protobuf::internal::ExtensionIdentifier<
                   SentencePieceText_SentencePiece, _proto_TypeTraits, _field_type, _is_packed>& id)
          const {
    return _proto_TypeTraits::Get(id.number(), _impl_._extensions_, id.default_value());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Singular::ConstType
      GetExtension(const ::google::protobuf::internal::ExtensionIdentifier<
                   SentencePieceText_SentencePiece, _proto_TypeTraits, _field_type, _is_packed>& id)
          const ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Get(GetArena(), id.number(), _impl_._extensions_,
                                  id.default_value());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Singular::MutableType MutableExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id)
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Mutable(GetArena(), id.number(), _field_type,
                                      &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void SetExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Singular::ConstType value) {
    _proto_TypeTraits::Set(GetArena(), id.number(), _field_type, value,
                           &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void SetAllocatedExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Singular::MutableType value) {
    _proto_TypeTraits::SetAllocated(GetArena(), id.number(), _field_type,
                                    value, &_impl_._extensions_);
  }
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void UnsafeArenaSetAllocatedExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Singular::MutableType value) {
    _proto_TypeTraits::UnsafeArenaSetAllocated(
        GetArena(), id.number(), _field_type, value, &_impl_._extensions_);
  }
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  [[nodiscard]] inline typename _proto_TypeTraits::Singular::MutableType
  ReleaseExtension(const ::google::protobuf::internal::ExtensionIdentifier<
                   SentencePieceText_SentencePiece, _proto_TypeTraits, _field_type, _is_packed>& id) {
    return _proto_TypeTraits::Release(GetArena(), id.number(), _field_type,
                                      &_impl_._extensions_);
  }
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Singular::MutableType
  UnsafeArenaReleaseExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) {
    return _proto_TypeTraits::UnsafeArenaRelease(
        GetArena(), id.number(), _field_type, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<!_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Repeated::ConstType
      GetExtension(
          const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                           _field_type, _is_packed>& id,
          int index) const {
    return _proto_TypeTraits::Get(id.number(), _impl_._extensions_, index);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Repeated::ConstType
      GetExtension(
          const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                           _field_type, _is_packed>& id,
          int index) const ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Get(id.number(), _impl_._extensions_, index);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Repeated::MutableType MutableExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      int index) ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Mutable(id.number(), index, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void SetExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      int index, typename _proto_TypeTraits::Repeated::ConstType value) {
    _proto_TypeTraits::Set(id.number(), index, value, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Repeated::MutableType AddExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id)
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    typename _proto_TypeTraits::Repeated::MutableType to_add =
        _proto_TypeTraits::Add(GetArena(), id.number(), _field_type,
                               &_impl_._extensions_);
    return to_add;
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void AddExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Repeated::ConstType value) {
    _proto_TypeTraits::Add(GetArena(), id.number(), _field_type, _is_packed,
                           value, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  PROTOBUF_FUTURE_ADD_NODISCARD inline const typename _proto_TypeTraits::
      Repeated::RepeatedFieldType&
      GetRepeatedExtension(
          const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                           _field_type, _is_packed>& id)
          const ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::GetRepeated(id.number(), _impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Repeated::RepeatedFieldType* PROTOBUF_NONNULL
  MutableRepeatedExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText_SentencePiece, _proto_TypeTraits,
                                       _field_type, _is_packed>& id)
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::MutableRepeated(
        GetArena(), id.number(), _field_type, _is_packed, &_impl_._extensions_);
  }
  // @@protoc_insertion_point(class_scope:sentencepiece.SentencePieceText.SentencePiece)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 5,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const SentencePieceText_SentencePiece& from_msg);
    ::google::protobuf::internal::ExtensionSet _extensions_;
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr piece_;
    ::google::protobuf::internal::ArenaStringPtr surface_;
    ::uint32_t id_;
    ::uint32_t begin_;
    ::uint32_t end_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_sentencepiece_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED SentencePieceText final : public ::google::protobuf::MessageLite
/* @@protoc_insertion_point(class_definition:sentencepiece.SentencePieceText) */ {
 public:
  inline SentencePieceText() : SentencePieceText(nullptr) {}
  ~SentencePieceText() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(SentencePieceText* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(SentencePieceText));
  }
#endif

  template <typename = void>
  explicit constexpr SentencePieceText(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline SentencePieceText(const SentencePieceText& from) : SentencePieceText(nullptr, from) {}
  inline SentencePieceText(SentencePieceText&& from) noexcept : SentencePieceText(nullptr, ::std::move(from)) {}
  inline SentencePieceText& operator=(const SentencePieceText& from) {
    CopyFrom(from);
    return *this;
  }
  inline SentencePieceText& operator=(SentencePieceText&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::std::string& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString);
  }
  [[nodiscard]] inline ::std::string* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::std::string>();
  }

  [[nodiscard]] static const SentencePieceText& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<SentencePieceText>(&SentencePieceText_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(SentencePieceText& a, SentencePieceText& b) { a.Swap(&b); }
  inline void Swap(SentencePieceText* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SentencePieceText* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] SentencePieceText* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::MessageLite::DefaultConstruct<SentencePieceText>(arena);
  }
  void CopyFrom(const SentencePieceText& from);
  void MergeFrom(const SentencePieceText& from) { SentencePieceText::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return IsInitializedImpl(*this);
  }

  private:
  static bool IsInitializedImpl(const MessageLite& msg);

  public:
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(SentencePieceText* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "sentencepiece.SentencePieceText"; }

  explicit SentencePieceText(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  SentencePieceText(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const SentencePieceText& from);
  SentencePieceText(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, SentencePieceText&& from) noexcept
      : SentencePieceText(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  // nested types ----------------------------------------------------
  using SentencePiece = SentencePieceText_SentencePiece;

  // accessors -------------------------------------------------------
  enum : int {
    kPiecesFieldNumber = 2,
    kTextFieldNumber = 1,
    kScoreFieldNumber = 3,
  };
  // repeated .sentencepiece.SentencePieceText.SentencePiece pieces = 2;
  [[nodiscard]] int pieces_size()
      const;
  private:
  int _internal_pieces_size() const;

  public:
  void clear_pieces() ;
  [[nodiscard]] const ::sentencepiece::SentencePieceText_SentencePiece& pieces(int index) const;
  [[nodiscard]] ::sentencepiece::SentencePieceText_SentencePiece* PROTOBUF_NONNULL mutable_pieces(int index);
  ::sentencepiece::SentencePieceText_SentencePiece* PROTOBUF_NONNULL add_pieces();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>&
  pieces() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>* PROTOBUF_NONNULL
  mutable_pieces();

  private:
  const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>& _internal_pieces() const;
  ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>* PROTOBUF_NONNULL _internal_mutable_pieces();

  public:
  // optional string text = 1;
  [[nodiscard]] bool has_text()
      const;
  void clear_text() ;
  [[nodiscard]] const ::std::string& text() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_text(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_text();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_text();
  void set_allocated_text(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_text() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_text(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_text();

  public:
  // optional float score = 3;
  [[nodiscard]] bool has_score()
      const;
  void clear_score() ;
  [[nodiscard]] float score() const;
  void set_score(float value);

  private:
  float _internal_score() const;
  void _internal_set_score(float value);

  public:
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            typename = typename _proto_TypeTraits::Singular>
  PROTOBUF_FUTURE_ADD_NODISCARD inline bool HasExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) const {
    return _impl_._extensions_.Has(id.number());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void ClearExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) {
    _impl_._extensions_.ClearExtension(id.number());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            typename = typename _proto_TypeTraits::Repeated>
  PROTOBUF_FUTURE_ADD_NODISCARD inline int ExtensionSize(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) const {
    return _impl_._extensions_.ExtensionSize(id.number());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<!_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Singular::ConstType
      GetExtension(const ::google::protobuf::internal::ExtensionIdentifier<
                   SentencePieceText, _proto_TypeTraits, _field_type, _is_packed>& id)
          const {
    return _proto_TypeTraits::Get(id.number(), _impl_._extensions_, id.default_value());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Singular::ConstType
      GetExtension(const ::google::protobuf::internal::ExtensionIdentifier<
                   SentencePieceText, _proto_TypeTraits, _field_type, _is_packed>& id)
          const ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Get(GetArena(), id.number(), _impl_._extensions_,
                                  id.default_value());
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Singular::MutableType MutableExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id)
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Mutable(GetArena(), id.number(), _field_type,
                                      &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void SetExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Singular::ConstType value) {
    _proto_TypeTraits::Set(GetArena(), id.number(), _field_type, value,
                           &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void SetAllocatedExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Singular::MutableType value) {
    _proto_TypeTraits::SetAllocated(GetArena(), id.number(), _field_type,
                                    value, &_impl_._extensions_);
  }
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void UnsafeArenaSetAllocatedExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Singular::MutableType value) {
    _proto_TypeTraits::UnsafeArenaSetAllocated(
        GetArena(), id.number(), _field_type, value, &_impl_._extensions_);
  }
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  [[nodiscard]] inline typename _proto_TypeTraits::Singular::MutableType
  ReleaseExtension(const ::google::protobuf::internal::ExtensionIdentifier<
                   SentencePieceText, _proto_TypeTraits, _field_type, _is_packed>& id) {
    return _proto_TypeTraits::Release(GetArena(), id.number(), _field_type,
                                      &_impl_._extensions_);
  }
  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Singular::MutableType
  UnsafeArenaReleaseExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id) {
    return _proto_TypeTraits::UnsafeArenaRelease(
        GetArena(), id.number(), _field_type, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<!_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Repeated::ConstType
      GetExtension(
          const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                           _field_type, _is_packed>& id,
          int index) const {
    return _proto_TypeTraits::Get(id.number(), _impl_._extensions_, index);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed,
            ::std::enable_if_t<_proto_TypeTraits::kLifetimeBound, int> = 0>
  PROTOBUF_FUTURE_ADD_NODISCARD inline
      typename _proto_TypeTraits::Repeated::ConstType
      GetExtension(
          const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                           _field_type, _is_packed>& id,
          int index) const ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Get(id.number(), _impl_._extensions_, index);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Repeated::MutableType MutableExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      int index) ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::Mutable(id.number(), index, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void SetExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      int index, typename _proto_TypeTraits::Repeated::ConstType value) {
    _proto_TypeTraits::Set(id.number(), index, value, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Repeated::MutableType AddExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id)
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    typename _proto_TypeTraits::Repeated::MutableType to_add =
        _proto_TypeTraits::Add(GetArena(), id.number(), _field_type,
                               &_impl_._extensions_);
    return to_add;
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline void AddExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id,
      typename _proto_TypeTraits::Repeated::ConstType value) {
    _proto_TypeTraits::Add(GetArena(), id.number(), _field_type, _is_packed,
                           value, &_impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  PROTOBUF_FUTURE_ADD_NODISCARD inline const typename _proto_TypeTraits::
      Repeated::RepeatedFieldType&
      GetRepeatedExtension(
          const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                           _field_type, _is_packed>& id)
          const ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::GetRepeated(id.number(), _impl_._extensions_);
  }

  template <typename _proto_TypeTraits, ::google::protobuf::internal::FieldType _field_type,
            bool _is_packed>
  inline typename _proto_TypeTraits::Repeated::RepeatedFieldType* PROTOBUF_NONNULL
  MutableRepeatedExtension(
      const ::google::protobuf::internal::ExtensionIdentifier<SentencePieceText, _proto_TypeTraits,
                                       _field_type, _is_packed>& id)
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _proto_TypeTraits::MutableRepeated(
        GetArena(), id.number(), _field_type, _is_packed, &_impl_._extensions_);
  }
  // @@protoc_insertion_point(class_scope:sentencepiece.SentencePieceText)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 3,
                          1, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const SentencePieceText& from_msg);
    ::google::protobuf::internal::ExtensionSet _extensions_;
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::sentencepiece::SentencePieceText_SentencePiece > pieces_;
    ::google::protobuf::internal::ArenaStringPtr text_;
    float score_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_sentencepiece_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED NBestSentencePieceText final : public ::google::protobuf::MessageLite
/* @@protoc_insertion_point(class_definition:sentencepiece.NBestSentencePieceText) */ {
 public:
  inline NBestSentencePieceText() : NBestSentencePieceText(nullptr) {}
  ~NBestSentencePieceText() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(NBestSentencePieceText* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(NBestSentencePieceText));
  }
#endif

  template <typename = void>
  explicit constexpr NBestSentencePieceText(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline NBestSentencePieceText(const NBestSentencePieceText& from) : NBestSentencePieceText(nullptr, from) {}
  inline NBestSentencePieceText(NBestSentencePieceText&& from) noexcept : NBestSentencePieceText(nullptr, ::std::move(from)) {}
  inline NBestSentencePieceText& operator=(const NBestSentencePieceText& from) {
    CopyFrom(from);
    return *this;
  }
  inline NBestSentencePieceText& operator=(NBestSentencePieceText&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::std::string& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::std::string>(::google::protobuf::internal::GetEmptyString);
  }
  [[nodiscard]] inline ::std::string* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::std::string>();
  }

  [[nodiscard]] static const NBestSentencePieceText& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<NBestSentencePieceText>(&NBestSentencePieceText_globals_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(NBestSentencePieceText& a, NBestSentencePieceText& b) { a.Swap(&b); }
  inline void Swap(NBestSentencePieceText* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(NBestSentencePieceText* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] NBestSentencePieceText* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::MessageLite::DefaultConstruct<NBestSentencePieceText>(arena);
  }
  void CopyFrom(const NBestSentencePieceText& from);
  void MergeFrom(const NBestSentencePieceText& from) { NBestSentencePieceText::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return IsInitializedImpl(*this);
  }

  private:
  static bool IsInitializedImpl(const MessageLite& msg);

  public:
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(NBestSentencePieceText* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "sentencepiece.NBestSentencePieceText"; }

  explicit NBestSentencePieceText(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  NBestSentencePieceText(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const NBestSentencePieceText& from);
  NBestSentencePieceText(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, NBestSentencePieceText&& from) noexcept
      : NBestSentencePieceText(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kNbestsFieldNumber = 1,
  };
  // repeated .sentencepiece.SentencePieceText nbests = 1;
  [[nodiscard]] int nbests_size()
      const;
  private:
  int _internal_nbests_size() const;

  public:
  void clear_nbests() ;
  [[nodiscard]] const ::sentencepiece::SentencePieceText& nbests(int index) const;
  [[nodiscard]] ::sentencepiece::SentencePieceText* PROTOBUF_NONNULL mutable_nbests(int index);
  ::sentencepiece::SentencePieceText* PROTOBUF_NONNULL add_nbests();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>&
  nbests() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>* PROTOBUF_NONNULL
  mutable_nbests();

  private:
  const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>& _internal_nbests() const;
  ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>* PROTOBUF_NONNULL _internal_mutable_nbests();

  public:
  // @@protoc_insertion_point(class_scope:sentencepiece.NBestSentencePieceText)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<0, 1,
                          1, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const NBestSentencePieceText& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::sentencepiece::SentencePieceText > nbests_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_sentencepiece_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// SentencePieceText_SentencePiece

// optional string piece = 1;
inline bool SentencePieceText_SentencePiece::has_piece() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void SentencePieceText_SentencePiece::clear_piece() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.piece_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& SentencePieceText_SentencePiece::piece() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.SentencePiece.piece)
  return _internal_piece();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void SentencePieceText_SentencePiece::set_piece(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.piece_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.SentencePiece.piece)
}
inline ::std::string* PROTOBUF_NONNULL SentencePieceText_SentencePiece::mutable_piece()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_piece();
  // @@protoc_insertion_point(field_mutable:sentencepiece.SentencePieceText.SentencePiece.piece)
  return _s;
}
inline const ::std::string& SentencePieceText_SentencePiece::_internal_piece() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.piece_.Get();
}
inline void SentencePieceText_SentencePiece::_internal_set_piece(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.piece_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL SentencePieceText_SentencePiece::_internal_mutable_piece() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.piece_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE SentencePieceText_SentencePiece::release_piece() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:sentencepiece.SentencePieceText.SentencePiece.piece)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.piece_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.piece_.Set("", GetArena());
  }
  return released;
}
inline void SentencePieceText_SentencePiece::set_allocated_piece(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.piece_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.piece_.IsDefault()) {
    _impl_.piece_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:sentencepiece.SentencePieceText.SentencePiece.piece)
}

// optional uint32 id = 2;
inline bool SentencePieceText_SentencePiece::has_id() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void SentencePieceText_SentencePiece::clear_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline ::uint32_t SentencePieceText_SentencePiece::id() const {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.SentencePiece.id)
  return _internal_id();
}
inline void SentencePieceText_SentencePiece::set_id(::uint32_t value) {
  _internal_set_id(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.SentencePiece.id)
}
inline ::uint32_t SentencePieceText_SentencePiece::_internal_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.id_;
}
inline void SentencePieceText_SentencePiece::_internal_set_id(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = value;
}

// optional string surface = 3;
inline bool SentencePieceText_SentencePiece::has_surface() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void SentencePieceText_SentencePiece::clear_surface() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.surface_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& SentencePieceText_SentencePiece::surface() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.SentencePiece.surface)
  return _internal_surface();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void SentencePieceText_SentencePiece::set_surface(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.surface_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.SentencePiece.surface)
}
inline ::std::string* PROTOBUF_NONNULL SentencePieceText_SentencePiece::mutable_surface()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_surface();
  // @@protoc_insertion_point(field_mutable:sentencepiece.SentencePieceText.SentencePiece.surface)
  return _s;
}
inline const ::std::string& SentencePieceText_SentencePiece::_internal_surface() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.surface_.Get();
}
inline void SentencePieceText_SentencePiece::_internal_set_surface(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.surface_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL SentencePieceText_SentencePiece::_internal_mutable_surface() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.surface_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE SentencePieceText_SentencePiece::release_surface() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:sentencepiece.SentencePieceText.SentencePiece.surface)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.surface_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.surface_.Set("", GetArena());
  }
  return released;
}
inline void SentencePieceText_SentencePiece::set_allocated_surface(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.surface_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.surface_.IsDefault()) {
    _impl_.surface_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:sentencepiece.SentencePieceText.SentencePiece.surface)
}

// optional uint32 begin = 4;
inline bool SentencePieceText_SentencePiece::has_begin() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  return value;
}
inline void SentencePieceText_SentencePiece::clear_begin() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.begin_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline ::uint32_t SentencePieceText_SentencePiece::begin() const {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.SentencePiece.begin)
  return _internal_begin();
}
inline void SentencePieceText_SentencePiece::set_begin(::uint32_t value) {
  _internal_set_begin(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.SentencePiece.begin)
}
inline ::uint32_t SentencePieceText_SentencePiece::_internal_begin() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.begin_;
}
inline void SentencePieceText_SentencePiece::_internal_set_begin(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.begin_ = value;
}

// optional uint32 end = 5;
inline bool SentencePieceText_SentencePiece::has_end() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  return value;
}
inline void SentencePieceText_SentencePiece::clear_end() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.end_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline ::uint32_t SentencePieceText_SentencePiece::end() const {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.SentencePiece.end)
  return _internal_end();
}
inline void SentencePieceText_SentencePiece::set_end(::uint32_t value) {
  _internal_set_end(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.SentencePiece.end)
}
inline ::uint32_t SentencePieceText_SentencePiece::_internal_end() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.end_;
}
inline void SentencePieceText_SentencePiece::_internal_set_end(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.end_ = value;
}

// -------------------------------------------------------------------

// SentencePieceText

// optional string text = 1;
inline bool SentencePieceText::has_text() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void SentencePieceText::clear_text() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.text_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& SentencePieceText::text() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.text)
  return _internal_text();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void SentencePieceText::set_text(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.text_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.text)
}
inline ::std::string* PROTOBUF_NONNULL SentencePieceText::mutable_text()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_text();
  // @@protoc_insertion_point(field_mutable:sentencepiece.SentencePieceText.text)
  return _s;
}
inline const ::std::string& SentencePieceText::_internal_text() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.text_.Get();
}
inline void SentencePieceText::_internal_set_text(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.text_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL SentencePieceText::_internal_mutable_text() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.text_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE SentencePieceText::release_text() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:sentencepiece.SentencePieceText.text)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.text_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.text_.Set("", GetArena());
  }
  return released;
}
inline void SentencePieceText::set_allocated_text(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.text_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.text_.IsDefault()) {
    _impl_.text_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:sentencepiece.SentencePieceText.text)
}

// repeated .sentencepiece.SentencePieceText.SentencePiece pieces = 2;
inline int SentencePieceText::_internal_pieces_size() const {
  return _internal_pieces().size();
}
inline int SentencePieceText::pieces_size() const {
  return _internal_pieces_size();
}
inline void SentencePieceText::clear_pieces() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.pieces_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::sentencepiece::SentencePieceText_SentencePiece& SentencePieceText::pieces(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.pieces)
  return _internal_pieces().Get(index);
}
inline ::sentencepiece::SentencePieceText_SentencePiece* PROTOBUF_NONNULL SentencePieceText::mutable_pieces(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:sentencepiece.SentencePieceText.pieces)
  return _internal_mutable_pieces()->Mutable(index);
}
inline ::sentencepiece::SentencePieceText_SentencePiece* PROTOBUF_NONNULL SentencePieceText::add_pieces()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::sentencepiece::SentencePieceText_SentencePiece* _add =
      _internal_mutable_pieces()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:sentencepiece.SentencePieceText.pieces)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>& SentencePieceText::pieces() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:sentencepiece.SentencePieceText.pieces)
  return _internal_pieces();
}
inline ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>* PROTOBUF_NONNULL
SentencePieceText::mutable_pieces() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:sentencepiece.SentencePieceText.pieces)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_pieces();
}
inline const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>&
SentencePieceText::_internal_pieces() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.pieces_;
}
inline ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText_SentencePiece>* PROTOBUF_NONNULL
SentencePieceText::_internal_mutable_pieces() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.pieces_;
}

// optional float score = 3;
inline bool SentencePieceText::has_score() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void SentencePieceText::clear_score() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.score_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline float SentencePieceText::score() const {
  // @@protoc_insertion_point(field_get:sentencepiece.SentencePieceText.score)
  return _internal_score();
}
inline void SentencePieceText::set_score(float value) {
  _internal_set_score(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:sentencepiece.SentencePieceText.score)
}
inline float SentencePieceText::_internal_score() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.score_;
}
inline void SentencePieceText::_internal_set_score(float value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.score_ = value;
}

// -------------------------------------------------------------------

// NBestSentencePieceText

// repeated .sentencepiece.SentencePieceText nbests = 1;
inline int NBestSentencePieceText::_internal_nbests_size() const {
  return _internal_nbests().size();
}
inline int NBestSentencePieceText::nbests_size() const {
  return _internal_nbests_size();
}
inline void NBestSentencePieceText::clear_nbests() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.nbests_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::sentencepiece::SentencePieceText& NBestSentencePieceText::nbests(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:sentencepiece.NBestSentencePieceText.nbests)
  return _internal_nbests().Get(index);
}
inline ::sentencepiece::SentencePieceText* PROTOBUF_NONNULL NBestSentencePieceText::mutable_nbests(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:sentencepiece.NBestSentencePieceText.nbests)
  return _internal_mutable_nbests()->Mutable(index);
}
inline ::sentencepiece::SentencePieceText* PROTOBUF_NONNULL NBestSentencePieceText::add_nbests()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::sentencepiece::SentencePieceText* _add =
      _internal_mutable_nbests()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:sentencepiece.NBestSentencePieceText.nbests)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>& NBestSentencePieceText::nbests() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:sentencepiece.NBestSentencePieceText.nbests)
  return _internal_nbests();
}
inline ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>* PROTOBUF_NONNULL
NBestSentencePieceText::mutable_nbests() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:sentencepiece.NBestSentencePieceText.nbests)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_nbests();
}
inline const ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>&
NBestSentencePieceText::_internal_nbests() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.nbests_;
}
inline ::google::protobuf::RepeatedPtrField<::sentencepiece::SentencePieceText>* PROTOBUF_NONNULL
NBestSentencePieceText::_internal_mutable_nbests() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.nbests_;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace sentencepiece


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // sentencepiece_2eproto_2epb_2eh
